<?php
/**
 * MagazineX dashboard page.
 *
 * Class MagazineX_Dashboard
 *
 * @package    MagazineX
 * @since      1.0.0
 */

// Exit if accessed directly.
defined( 'ABSPATH' ) || exit;

/**
 * Class MagazineX_Dashboard
 */
class MagazineX_Dashboard {

	/**
	 * Instance of class MagazineX_Dashboard.
	 *
	 * @var $instance
	 *
	 * @since 1.0.0
	 * @static
	 */
	private static $instance;

	/**
	 * Initiator.
	 *
	 * @since 1.0.0
	 * @static
	 *
	 * @return object MagazineX_Dashboard
	 */
	public static function instance() {

		if ( is_null( self::$instance ) ) {
			self::$instance = new self();
		}

		return self::$instance;
	}

	/**
	 * MagazineX_Dashboard constructor.
	 *
	 * @since 1.0.0
	 *
	 * @return void
	 */
	private function __construct() {
		$this->setup_hooks();
	}

	/**
	 * Setup hooks.
	 *
	 * @since 1.0.0
	 *
	 * @return void
	 */
	private function setup_hooks() {
		add_action( 'admin_menu', array( $this, 'admin_menu' ) );
	}

	/**
	 * Create menu.
	 *
	 * @since 1.0.0
	 *
	 * @return void
	 */
	public function admin_menu() {

		/* translators: %s: Theme Name. */
		$theme_page_name = sprintf( esc_html__( '%s Options', 'magazinex' ), 'MagazineX' );

		$theme_page = add_theme_page(
			$theme_page_name,
			$theme_page_name,
			'edit_theme_options',
			'magazinex-options',
			array(
				$this,
				'option_page',
			)
		);

	}

	/**
	 * Option page markup.
	 *
	 * @since 1.0.0
	 *
	 * @return void
	 */
	public function option_page() {

		$customize_options = array(
			'site_logo' => array(
				'label' => __( 'Upload Logo', 'magazinex' ),
				'link'  => admin_url( 'customize.php?autofocus[control]=custom_logo' ),
				'icon'  => 'dashicons-format-image',
			),
			'colors'    => array(
				'label' => __( 'Set Color', 'magazinex' ),
				'link'  => admin_url( 'customize.php?autofocus[section]=magazinex_global_colors_section' ),
				'icon'  => 'dashicons-admin-appearance',
			),
			'header'    => array(
				'label' => __( 'Header Options', 'magazinex' ),
				'link'  => admin_url( 'customize.php?autofocus[panel]=magazinex_header_navigation_panel' ),
				'icon'  => 'dashicons-insert-before',
			),
			'blog'      => array(
				'label' => __( 'Blog Options', 'magazinex' ),
				'link'  => admin_url( 'customize.php?autofocus[section]=magazinex_blog_section' ),
				'icon'  => ' dashicons-editor-bold',
			),
			'footer'    => array(
				'label' => __( 'Footer Options', 'magazinex' ),
				'link'  => admin_url( 'customize.php?autofocus[panel]=magazinex_footer_panel' ),
				'icon'  => 'dashicons-insert-after',
			),
		);
		?>
		<div class="wrap">
			<div class="metabox-holder">
				<div class="mzx-header" >
					<div class="mzx-container">
						<div class="mzx-title">
							<img class="mzx-icon" src="<?php echo esc_url( get_stylesheet_directory_uri() . '/inc/admin/assets/icons/magazinex.png' ); ?>" alt="magazinex">
							<span class="mzx-version">
									<?php
									echo esc_html( self::get_theme()->Version );
									?>
							</span>
						</div>
					</div><!--/.mzx-container-->
				</div> <!--/.mzx-header-->
				<div class="mzx-container">
					<div class="postbox-container" style="float: none;">
						<div class="col-70">
							<h2 style="height:0;margin:0;"><!-- admin notices below this element --></h2>
							<div class="postbox">
								<h3 class="hndle"><?php esc_html_e( 'Quick customize settings', 'magazinex' ); ?></h3>
								<div class="inside mzx-quick-settings-section" style="padding: 0;margin: 0;">
									<ul>
										<?php foreach ( $customize_options as $customize_option ) : ?>
											<li>
												<a href="<?php echo esc_url( $customize_option['link'] ); ?>" target="_blank">
													<span class="dashicons <?php echo esc_attr( $customize_option['icon'] ); ?>"></span>
													<h4><?php echo esc_html( $customize_option['label'] ); ?></h4>
												</a>
											</li>
										<?php endforeach; ?>
									</ul>
								</div>
							</div>
						</div> <!--/.col-70-->
						<div class="col-30">
							<div class="postbox">
								<h3 class="hndle" ><span class="dashicons dashicons-download"></span><span><?php esc_html_e( 'Starter Demo', 'magazinex' ); ?></span></h3>
								<div class="inside">
									<p><?php esc_html_e( 'You do not need to build your store from scratch, MagazineX provides a starter demo site.', 'magazinex' ); ?></p>
									<p><?php esc_html_e( 'Import demo site and start editing as you like.', 'magazinex' ); ?></p>
									<a href="<?php echo esc_url( admin_url( 'plugin-install.php?s=themegrill+demo+importer&tab=search' ) ); ?>"><?php esc_html_e( 'Install ThemeGrill Demo Importer plugin', 'magazinex' ); ?></a>
								</div>
							</div>
							<div class="postbox">
								<h3 class="hndle"><span class="dashicons dashicons-thumbs-up"></span><span><?php esc_html_e( 'Review', 'magazinex' ); ?></span></h3>
								<div class="inside">
									<p>
										<?php
										echo sprintf(
										/* translators: 1: Theme Name, 2: Review Link. */
											esc_html__( 'Love using %1$s? Help us by leaving a review %2$s', 'magazinex' ),
											'MagazineX',
											'<a href="' . esc_url( 'https://wordpress.org/support/theme/magazinex/reviews/?filter=5/#new-post' ) . '" target="_blank">' . esc_html__( 'here &#129066;', 'magazinex' ) . '</a>'
										);
										?>
									</p>
								</div>
							</div>
						</div><!--/.col-30-->
					</div><!--/.postbox-container-->
				</div><!--/.mzx-container-->
			</div><!--/.metabox-holder-->
		</div><!--/.wrap-->
		<?php
	}

	/**
	 * Get theme.
	 *
	 * @since 1.0.0
	 *
	 * @return false|WP_Theme
	 */
	public static function get_theme() {

		if ( ! is_child_theme() ) {
			$theme = wp_get_theme();
		} else {
			$theme = wp_get_theme()->parent();
		}

		return $theme;
	}
}

MagazineX_Dashboard::instance();
