<?php
/**
 * Adds classes to appropriate places.
 *
 * @package magazinex
 */

// Exit if accessed directly.
defined( 'ABSPATH' ) || exit;

if ( ! class_exists( 'MagazineX_Css_Classes' ) ) :
	/**
	 * Adds css classes
	 */
	class MagazineX_Css_Classes {

		/**
		 * Constructor.
		 */
		public function __construct() {
			add_filter(
				'mzx_footer_widget_container_class',
				array(
					$this,
					'mzx_add_footer_widget_container_classes',
				)
			);

			add_filter(
				'mzx_header_bar_widget_container_class',
				array(
					$this,
					'mzx_add_header_bar_widget_container_classes',
				)
			);


			add_filter( 'magazinex_primary_menu_class', array( $this, 'magazinex_add_primary_menu_classes' ) );

			add_filter( 'mzx_header_actions_container_class', array( $this, 'mzx_add_header_actions_container_classes' ) );

		}

		/**
		 * Adds css classes into the footer widget area
		 *
		 * @param array $classes list of old classes.
		 *
		 * @return array
		 */
		public function mzx_add_footer_widget_container_classes( $classes ) {
			$footer_column_layout = get_theme_mod( 'magazinex_footer_column_layout_1_style', 'style-3' );
			$footer_column        = preg_replace( '/\D/', '', $footer_column_layout );

			$classes[] = "mzx-grid-cols--{$footer_column}";

			return $classes;
		}

		/**
		 * Adds css classes into primary menu
		 *
		 * @param array $classes list of old classes.
		 *
		 * @return array
		 */
		public function magazinex_add_primary_menu_classes( $classes ) {
			if ( magazinex_is_magazinex_pro_active() ) {
				$menu_style = get_theme_mod( 'magazinex_primary_menu_layout_1_style', 'style-1' );

				$classes[] = "mzx-primary-menu mzx-primary-menu--layout-1 mzx-primary-menu--layout-1-{$menu_style}";

				if ( get_theme_mod( 'magazinex_enable_priority_plus_primary_menu', 0 ) ) {
					$classes[] = 'mzx-extra-menus';
				}
			} else {
				$classes[] = 'mzx-primary-menu mzx-primary-menu--layout-1 mzx-primary-menu--layout-1-style-1';
			}

			return $classes;
		}

		/**
		 * Adds css classes into the header bar widget area
		 *
		 * @param array $classes list of old classes.
		 *
		 * @return array
		 */
		public function mzx_add_header_bar_widget_container_classes( $classes ) {
			if ( magazinex_is_magazinex_pro_active() ) {
				$header_bar_container = get_theme_mod( 'magazinex_header_bar_layout', 'layout-3' );
				$header_bar           = preg_replace( '/\D/', '', $header_bar_container );

				$classes[] = "mzx-grid-cols-{$header_bar}";
			} else {
				$classes[] = 'mzx-grid-cols-3';
			}

			return $classes;
		}

		public function mzx_add_header_actions_container_classes( $classes ) {
			if ( magazinex_is_magazinex_pro_active() ) {
				$header_actions_container_class = get_theme_mod( 'magazinex_header_search_position', 'position-1' );

				$classes[] = "mzx-header-actions mzx-header-actions--{$header_actions_container_class}";
			} else {
				$classes[] = 'mzx-header-actions';
			}

			return $classes;
		}
	}
endif;
new MagazineX_Css_Classes();
