<?php
/**
 * MagazineX dynamic CSS generation file for theme options.
 *
 * Class MagazineX_Dynamic_CSS
 *
 * @package    MagazineX
 * @since      1.0.0
 */

// Exit if accessed directly.
defined( 'ABSPATH' ) || exit;

/**
 * MagazineX dynamic CSS generation file for theme options.
 *
 * Class MagazineX_Dynamic_CSS
 */
class MagazineX_Dynamic_CSS {

	/**
	 * Return dynamic CSS output.
	 *
	 * @param string $dynamic_css          Dynamic CSS.
	 * @param string $dynamic_css_filtered Dynamic CSS Filters.
	 *
	 * @return string Generated CSS.magazinex_primary_menu_text_color
	 */
	public static function get_css( $dynamic_css = '', $dynamic_css_filtered = '' ) {
		$steps = apply_filters( 'mzx_color_darken_factor', -25 );

		/**
		 * Default Values.
		 */
		// Top Bar.
		$header_top_background_default = array(
			'background-color'      => '#F2F3FF',
			'background-image'      => '',
			'background-position'   => 'center center',
			'background-size'       => 'auto',
			'background-attachment' => 'scroll',
			'background-repeat'     => 'repeat',
		);

		/**
		 * Variable declarations.
		 */
		// Global.
		$primary_color    = get_theme_mod( 'magazinex_primary_color', '#BA81FF' );
		$headings_color   = get_theme_mod( 'magazinex_headings_color', '#111111' );
		$link_color       = get_theme_mod( 'magazinex_link_color', '#111111' );
		$link_hover_color = get_theme_mod( 'magazinex_link_hover_color', '#BA81FF' );

		// Top Bar.
		$header_top_background = get_theme_mod( 'magazinex_header_bar_background', $header_top_background_default );

		// Header.
		$logo_height            = get_theme_mod( 'magazinex_logo_height', '' );
		$site_title_color       = get_theme_mod( 'magazinex_site_title_color', '#181818' );
		$tagline_color          = get_theme_mod( 'magazinex_tagline_color', '#000' );
		$site_title_hover_color = get_theme_mod( 'magazinex_site_title_hover_color', '#C7AB62' );

		// Primary menu.
		$primary_menu_text_color        = get_theme_mod( 'magazinex_primary_menu_text_color', '' );
		$primary_menu_text_hover_color  = get_theme_mod( 'magazinex_primary_menu_text_hover_color', '' );
		$primary_menu_text_active_color = get_theme_mod( 'magazinex_primary_menu_text_active_color', '' );
		$hamburger_icon_color           = get_theme_mod( 'magazinex_hamburger_icon_color', '' );
		$hamburger_icon_hover_color     = get_theme_mod( 'magazinex_hamburger_icon_hover_color', '' );

		// General.
		$background_color = get_theme_mod( 'magazinex_inside_container_background', '#F5F9FF' );

		// Sub menu.
		$sub_menu_text_color        = get_theme_mod( 'magazinex_sub_menu_text_color', '' );
		$sub_menu_text_hover_color  = get_theme_mod( 'magazinex_sub_menu_text_hover_color', '' );
		$sub_menu_text_active_color = get_theme_mod( 'magazinex_sub_menu_text_active_color', '' );

		// Drawer.
		$drawer_background_color = get_theme_mod( 'magazinex_header_drawer_content_background', '' );

		// Footer column.
		$footer_col_background_color = get_theme_mod( 'magazinex_footer_column_background', '' );
		$footer_col_heading_color    = get_theme_mod( 'magazinex_footer_column_headings_color', '' );
		$footer_col_text_color       = get_theme_mod( 'magazinex_footer_column_text_color', '' );
		$footer_col_link_color       = get_theme_mod( 'magazinex_footer_column_link_color', '' );

		// Footer bar.
		$footer_bar_background_color = get_theme_mod( 'magazinex_footer_bar_background', '' );
		$footer_bar_text_color       = get_theme_mod( 'magazinex_footer_bar_text_color', '' );
		$footer_bar_link_color       = get_theme_mod( 'magazinex_footer_bar_link_color', '' );
		$footer_bar_link_hover_color = get_theme_mod( 'magazinex_footer_bar_link_hover_color', '' );

		/**
		 * Generate dynamic CSS.
		 */
		$parse_css = '';

		// Primary Color.
		$primary_color_css = array(
			'.site-header a:hover,
			.mzx-primary-nav li:hover > a,
			.mzx-primary-nav li:focus > a,
			.mzx-primary-nav li.focus > a,
			.mzx-primary-nav ul ul li.current-menu-item > a,
			.mzx-primary-nav ul ul li.current_page_item > a,
			.mzx-mobile-nav  li:hover > a,
			.mzx-mobile-nav  li:focus > a,
			.mzx-secondary-menu li:hover > a,
			.mzx-secondary-menu li:focus > a,
			.mzx-tertiary-navigation li a:hover,
			.mzx-tertiary-navigation li a:focus,
			.mzx-primary-nav .current_page_ancestor > a,
			.mzx-primary-nav .current-menu-ancestor > a,
			.mzx-mobile-nav  .current_page_item > a,
			.mzx-mobile-nav  .current-menu-item > a,
			.mzx-mobile-nav  .current_page_ancestor > a,
			.mzx-mobile-nav  .current-menu-ancestor > a,
			.mzx-secondary-menu .current_page_item > a,
			.mzx-secondary-menu .current-menu-item > a,
			.mzx-secondary-menu .current_page_ancestor > a,
			.mzx-secondary-menu .current-menu-ancestor > a,
			.mzx-tertiary-navigation .current_page_item > a,
			.mzx-tertiary-navigation .current-menu-item > a,
			.secondary-menu-toggle:hover,
			.secondary-menu-toggle:focus,
			.entry-summary a:hover,
			.entry-content a:hover,
			.entry-header a:hover,
			.entry-meta a:hover,
			.tertiary-menu-toggle:hover,
			.tertiary-menu-toggle:focus,
			.mzx-page-header .trail-items a:hover,
			.mzx-page-header .trail-items a:focus,
			.site-sidebar a:hover,
			.site-sidebar a:focus,
			.site-sidebar .mzx-no-widget a,
			.no-results .page-content a,
			.mzx-footer li a:hover,
			.mzx-footer li a:focus,
			.post-navigation .nav-next a:hover,
			.post-navigation .nav-next a:focus,
			.post-navigation .nav-previous a:hover,
			.post-navigation .nav-previous a:focus,
			.post-navigation .nav-links a:hover,
			.post-navigation .nav-links a:focus,
			.mzx-filter-sidebar-toggle:hover,
			.mzx-filter-sidebar-toggle:focus,
			.mzx-entry-cta .read-more-text
			.article-content a:hover,
			.article-content a:focus,
			.mzx-footer-bar a:hover,
			.mzx-footer-bar a:focus,
			.mzx-breaking-news span,
			.mzx-primary-nav .current_page_item > a,
			.mzx-primary-nav .current-menu-item > a,
			.mzx-primary-nav .current_page_ancestor > a,
			.mzx-primary-nav .current-menu-ancestor > a,
			.mzx-mobile-nav  .current_page_item > a,
			.mzx-mobile-nav  .current-menu-item > a,
			.mzx-mobile-nav  .current_page_ancestor > a,
			.mzx-mobile-nav  .current-menu-ancestor > a,
			.mzx-secondary-menu .current_page_item > a,
			.mzx-secondary-menu .current-menu-item > a,
			.mzx-secondary-menu .current_page_ancestor > a,
			.mzx-secondary-menu .current-menu-ancestor > a,
			.mzx-page-header .trail-items a,
			.entry-meta > span .entry-date:hover,
			.comments-area .comment-meta .vcard a:hover,
			.comments-area .comment-meta .vcard a:focus,
			.comments-area .comment-reply-link,
			.mzx-footer-cols .mzb-post-list .mzb-post-title a:hover'
			=> array(
				'color' => esc_html( $primary_color ),
			),

			'.mzx-primary-nav ul li.current-menu-item:before,
			.mzx-primary-nav .current_page_item > a::before,
			.mzx-primary-nav .current-menu-item > a::before,
			.mzx-primary-nav .current_page_ancestor > a::before,
			.mzx-primary-nav .current-menu-ancestor > a::before,
			.mzx-mobile-nav  .current_page_item > a::before,
			.mzx-mobile-nav  .current-menu-item > a::before,
			.mzx-mobile-nav  .current_page_ancestor > a::before,
			.mzx-mobile-nav  .current-menu-ancestor > a::before,
			.mzx-secondary-menu .current_page_item > a::before,
			.mzx-secondary-menu .current-menu-item > a::before,
			.mzx-secondary-menu .current_page_ancestor > a::before,
			.mzx-secondary-menu .current-menu-ancestor > a::before,
			.comments-area .comment-respond .comment-reply-title::before,
			.mzx-searchbox-close-icon:hover,
			.comments-area .comments-title::before,
			.mzx-searchbox-icon:active,
			.mzx-searchbox-icon:focus,
			.mzx-searchbox-close-icon:active,
			.mzx-searchbox-close-icon:focus'
			=> array(
				'background-color' => esc_html( $primary_color ),
			),

			'button,
			button:hover,
			button:active,
			button:focus,
			input[type="submit"],
			input[type="button"]:hover,
			input[type="button"]:active,
			input[type="button"]:focus,
			input[type="reset"]:hover,
			input[type="reset"]:active,
			input[type="reset"]:focus,
			input[type="submit"]:hover,
			input[type="submit"]:active,
			input[type="submit"]:focus,
			.wp-block-button__link,
			.wp-block-button__link:hover,
            .wp-block-button__link:active,
            .wp-block-button__link:focus,

			.wp-block-search .wp-block-search__button:hover,
			.wp-block-search .wp-block-search__button:active,
			.wp-block-search .wp-block-search__button:focus,
			.mzx-scroll-to-top:hover,
			.mzx-searchbox-icon, .mzx-searchbox-close-icon'
			=> array(
				'border-color'     => MagazineX_Utils::adjust_color_brightness( $primary_color, $steps ),
				'background-color' => MagazineX_Utils::adjust_color_brightness( $primary_color, $steps ),
			),

			'.mzx-searchbox-icon, .mzx-searchbox-close-icon'
			=> array(
				'background-color' => MagazineX_Utils::adjust_color_opacity( $primary_color, 10 ),
			),

			'button,
			input[type="button"],
			input[type="reset"],
			input[type="submit"],
			.wp-block-button__link,
			.button,
			.added_to_cart,
			button:hover, button:active, button:focus,
			input[type="button"]:hover,
			input[type="button"]:active,
			input[type="button"]:focus,
			input[type="reset"]:hover,
			input[type="reset"]:active,
			input[type="reset"]:focus,
			input[type="submit"]:hover,
			input[type="submit"]:active,
			input[type="submit"]:focus,
			.wp-block-button__link:hover,
			.wp-block-button__link:active,
			.wp-block-button__link:focus,
			.button:hover,
			.button:active,
			.button:focus,
			.added_to_cart:hover,
			.added_to_cart:active,
			.added_to_cart:focus,
			.error-404 .mzx-btn,
			.error-404 .mzx-btn:hover,
			.error-404 .mzx-btn:active,
			.error-404 .mzx-btn:focus,
			.entry-header .post-categories a,
			.page-numbers li:hover > a,
			.page-numbers .current'
			=> array(
				'color' => '#FFF',
			),

			'button,
			input[type="button"],
			input[type="reset"],
			.wp-block-button__link,
			.button,
			.wp-block-search .wp-block-search__button,
			.wp-block-group h2::before,
			.added_to_cart,
			.mzx-search:hover button,
			.mzx-search:focus button,
			.tertiary-menu-toggle:hover .mzx-drawer-toggle,
			.tertiary-menu-toggle:focus .mzx-drawer-toggle,
			.page-numbers li:hover > a,
			.page-numbers .current,
			.widget-title::before,
			.mzx-scroll-to-top,
			.entry-header .post-categories a,
			.site-sidebar .widget-title::before,
			.entry-footer .mzx-entry-cta,
			.mzx-related-posts h2.mzx-related-posts-header::before,
			.mzx-primary-nav ul li.current-menu-item:hover::before,
			.mzx-searchbox-icon:hover,
			.mzx-primary-nav li.current_page_item::before'
			=> array(
				'background-color' => esc_html( $primary_color ),
			),

			'input[type="text"],
			input[type="email"],
			input[type="url"],
			input[type="password"],
			input[type="search"],
			input[type="number"],
			input[type="tel"],
			input[type="range"],
			input[type="date"],
			input[type="month"],
			input[type="week"],
			input[type="time"],
			input[type="datetime"],
			input[type="datetime-local"],
			input[type="color"],
			.wp-block-search .wp-block-search__button,
			textarea,
			.button,
			.entry-footer .mzx-entry-cta,
			.menu-toggle span,
			.mzx-search.open .search-form .search-field,
			.mzx-search.open .search-field'
			=> array(
				'border-color' => esc_html( $primary_color ),
			),

			'.mzx-icon,
			.mzx-entry-cta .mzx-icon,
			.entry-meta .mzx-icon,
			.mzx-search .mzx-icon--search,
			.mzx-primary-nav li:hover > .mzx-submenu-toggle .mzx-icon,
			.mzx-primary-nav li:focus > .mzx-submenu-toggle .mzx-icon,
			.mzx-primary-nav li.focus > .mzx-submenu-toggle .mzx-icon,
			.mzx-mobile-nav  li:hover > .mzx-submenu-toggle .mzx-icon,
			.mzx-mobile-nav  li:focus > .mzx-submenu-toggle .mzx-icon,
			.mzx-mobile-nav  li.focus > .mzx-submenu-toggle .mzx-icon,
			.mzx-secondary-menu li:hover > .mzx-submenu-toggle .mzx-icon,
			.mzx-secondary-menu li:focus > .mzx-submenu-toggle .mzx-icon,
			.mzx-secondary-menu li.focus > .mzx-submenu-toggle .mzx-icon,
			.mzx-primary-nav .current_page_ancestor > .mzx-submenu-toggle .mzx-icon,
			.mzx-primary-nav .current-menu-ancestor > .mzx-submenu-toggle .mzx-icon,
			.mzx-mobile-nav  .current_page_item > .mzx-submenu-toggle .mzx-icon,
			.mzx-mobile-nav  .current-menu-item > .mzx-submenu-toggle .mzx-icon,
			.mzx-mobile-nav  .current_page_ancestor > .mzx-submenu-toggle .mzx-icon,
			.mzx-mobile-nav  .current-menu-ancestor > .mzx-submenu-toggle .mzx-icon,
			.mzx-secondary-menu .current_page_item > .mzx-submenu-toggle .mzx-icon,
			.mzx-secondary-menu .current_page_ancestor > .mzx-submenu-toggle .mzx-icon,
			.mzx-secondary-menu .current-menu-ancestor > .mzx-submenu-toggle .mzx-icon,
			.secondary-menu-toggle:hover .mzx-drawer-toggle .mzx-icon,
			.secondary-menu-toggle:focus .mzx-drawer-toggle .mzx-icon,
			.mzx-secondary-menu .current-menu-item > .mzx-submenu-toggle .mzx-icon,
			.mzx-primary-nav .current-menu-item > .mzx-submenu-toggle .mzx-icon,
			.mzx-primary-nav .current_page_item > .mzx-submenu-toggle .mzx-icon'
			=> array(
				'fill' => esc_html( $primary_color ),
			),

			'blockquote'
			=> array(
				'border-left-color' => esc_html( $primary_color ),
			),
		);

		$parse_css .= self::magazinex_parse_css( '#C7AB62', $primary_color, $primary_color_css );

		// Headings Color.
		$headings_color_css = array(
			'h1,
			h2,
			h3,
			h4,
			h5,
			h6'
			=> array(
				'color' => esc_html( $headings_color ),
			),
		);

		$parse_css .= self::magazinex_parse_css( '#111111', $headings_color, $headings_color_css );

		// Link Color.
		$link_color_css = array(
			'.entry-summary a, .entry-content a' => array(
				'color' => esc_html( $link_color ),
			),
		);

		$parse_css .= self::magazinex_parse_css( '#111111', $link_color, $link_color_css );

		// Link Color.
		$link_hover_color_css = array(
			'.entry-summary a:hover, .entry-content a:hover' => array(
				'color' => esc_html( $link_hover_color ),
			),
		);

		$parse_css .= self::magazinex_parse_css( '#BA81FF', $link_hover_color, $link_hover_color_css );

		$parse_css .= self::magazinex_parse_background_css( $header_top_background_default, $header_top_background, '.mzx-site-top-bar' );

		$site_title_color_css = array(
			'.mzx-site-title a'
			=> array(
				'color' => esc_html( $site_title_color ),
			),
		);

		$parse_css .= self::magazinex_parse_css( '#181818', $site_title_color, $site_title_color_css );

		$tagline_color_css = array(
			'.mzx-site-info p'
			=> array(
				'color' => esc_html( $tagline_color ),
			),
		);

		$parse_css .= self::magazinex_parse_css( '#000', $tagline_color, $tagline_color_css );

		$site_title_hover_color_css = array(
			'.mzx-site-title a:hover,
			.mzx-site-title a:focus'
			=> array(
				'color' => esc_html( $site_title_hover_color ),
			),
		);

		$parse_css .= self::magazinex_parse_css( '#C7AB62', $site_title_hover_color, $site_title_hover_color_css );

		// Site logo height.
		$logo_height_css = array(
			'.custom-logo'
			=> array(
				'max-height' => esc_html( (int) $logo_height ) . 'px',
			),
		);

		$parse_css .= self::magazinex_parse_css( '', $logo_height, $logo_height_css );

		// General.
		$background_color_css = array(
			'.mzx-content'
			=> array(
				'background-color' => esc_html( $background_color ),
			),
		);

		$parse_css .= self::magazinex_parse_css( '#F5F9FF', $background_color, $background_color_css );

		// Primary Header.
		$main_header_background_default = array(
			'background-color'      => '#FFFFFF',
			'background-image'      => '',
			'background-position'   => 'center center',
			'background-size'       => 'auto',
			'background-attachment' => 'scroll',
			'background-repeat'     => 'repeat',
		);
		$main_header_background         = get_theme_mod( 'magazinex_main_header_background', $header_top_background_default );
		$parse_css                     .= self::magazinex_parse_background_css( $main_header_background_default, $main_header_background, '.mzx-header-1' );

		// Primary menu.
		$primary_menu_text_color_css = array(
			'.mzx-primary-nav a,
			.mzx-mobile-nav  a'
			=> array(
				'color' => esc_html( $primary_menu_text_color ),
			),

			'.mzx-primary-nav .mzx-icon,
			.mzx-mobile-nav  .mzx-icon'
			=> array(
				'fill' => esc_html( $primary_menu_text_color ),
			),
		);

		$parse_css .= self::magazinex_parse_css( '', $primary_menu_text_color, $primary_menu_text_color_css );

		$primary_menu_text_hover_color_css = array(
			'.mzx-primary-nav li:hover > a,
			.mzx-primary-nav li:focus > a,
			.mzx-primary-nav li.focus > a,
			.mzx-mobile-nav  li:hover > a,
			.mzx-mobile-nav  li:focus > a,
			.mzx-mobile-nav  li.focus > a'
			=> array(
				'color' => esc_html( $primary_menu_text_hover_color ),
			),

			'.mzx-primary-nav li:hover > .mzx-submenu-toggle .mzx-icon,
			.mzx-primary-nav li:focus > .mzx-submenu-toggle .mzx-icon,
			.mzx-primary-nav li.focus > .mzx-submenu-toggle .mzx-icon,
			.mzx-mobile-nav  li:hover > .mzx-submenu-toggle .mzx-icon,
			.mzx-mobile-nav  li:focus > .mzx-submenu-toggle .mzx-icon,
			.mzx-mobile-nav  li.focus > .mzx-submenu-toggle .mzx-icon'
			=> array(
				'fill' => esc_html( $primary_menu_text_hover_color ),
			),
		);

		$parse_css .= self::magazinex_parse_css( '', $primary_menu_text_hover_color, $primary_menu_text_hover_color_css );

		$primary_menu_text_active_color_css = array(
			'.mzx-primary-nav .current_page_item > a,
			.mzx-primary-nav .current-menu-item > a,
			.mzx-primary-nav .current_page_ancestor > a,
			.mzx-primary-nav .current-menu-ancestor > a,
			.mzx-mobile-nav  .current_page_item > a,
			.mzx-mobile-nav  .current-menu-item > a,
			.mzx-mobile-nav  .current_page_ancestor > a,
			.mzx-mobile-nav  .current-menu-ancestor > a,
			.mzx-primary-nav ul ul li.current-menu-item > a,
			.mzx-primary-nav ul ul li.current_page_item > a'
			=> array(
				'color' => esc_html( $primary_menu_text_active_color ),
			),

			'.mzx-primary-nav .current_page_item > .mzx-submenu-toggle .mzx-icon,
			.mzx-primary-nav .current-menu-item > .mzx-submenu-toggle .mzx-icon,
			.mzx-primary-nav .current_page_ancestor > .mzx-submenu-toggle .mzx-icon,
			.mzx-primary-nav .current-menu-ancestor > .mzx-submenu-toggle .mzx-icon,
			.mzx-mobile-nav  .current_page_item > .mzx-submenu-toggle .mzx-icon,
			.mzx-mobile-nav  .current-menu-item > .mzx-submenu-toggle .mzx-icon,
			.mzx-mobile-nav  .current_page_ancestor > .mzx-submenu-toggle .mzx-icon,
			.mzx-mobile-nav  .current-menu-ancestor > .mzx-submenu-toggle .mzx-icon'
			=> array(
				'fill' => esc_html( $primary_menu_text_active_color ),
			),
		);

		$parse_css .= self::magazinex_parse_css( '', $primary_menu_text_active_color, $primary_menu_text_active_color_css );

		$hamburger_icon_color_css = array(
			'.menu-toggle span'
			=> array(
				'border-color' => esc_html( $hamburger_icon_color ),
			),
		);

		$parse_css .= self::magazinex_parse_css( '', $hamburger_icon_color, $hamburger_icon_color_css );

		$hamburger_icon_hover_color_css = array(
			'.menu-toggle:hover span'
			=> array(
				'border-color' => esc_html( $hamburger_icon_hover_color ),
			),
		);

		$parse_css .= self::magazinex_parse_css( '', $hamburger_icon_hover_color, $hamburger_icon_hover_color_css );

		// Sub menu.
		$sub_menu_text_color_css = array(
			'.mzx-primary-nav ul ul a'
			=> array(
				'color' => esc_html( $sub_menu_text_color ),
			),
		);

		$parse_css .= self::magazinex_parse_css( '#111111', $sub_menu_text_color, $sub_menu_text_color_css );

		$sub_menu_text_hover_color_css = array(
			'.mzx-primary-nav ul ul li:hover > a,
			.mzx-primary-nav ul ul li.current-menu-item:hover > a,
			.mzx-primary-nav ul ul li.current_page_item:hover > a'
			=> array(
				'color' => esc_html( $sub_menu_text_hover_color ),
			),

			'.mzx-primary-nav ul ul li.current-menu-item:hover > .mzx-submenu-toggle .mzx-icon,
			mzx-primary-nav ul ul li.current_page_item:hover > .mzx-submenu-toggle .mzx-icon'
			=> array(
				'fill' => esc_html( $sub_menu_text_hover_color ),
			),
		);

		$parse_css .= self::magazinex_parse_css( '#BA81FF', $sub_menu_text_hover_color, $sub_menu_text_hover_color_css );

		$sub_menu_text_active_color_css = array(
			'.mzx-primary-nav ul ul li.current-menu-item > a,
			.mzx-primary-nav ul ul li.current_page_item > a'
			=> array(
				'color' => esc_html( $sub_menu_text_active_color ),
			),

			'.mzx-primary-nav ul ul li.current-menu-item > .mzx-submenu-toggle .mzx-icon,
			mzx-primary-nav ul ul li.current_page_item > .mzx-submenu-toggle .mzx-icon'
			=> array(
				'fill' => esc_html( $sub_menu_text_active_color ),
			),
		);

		$parse_css .= self::magazinex_parse_css( '', $sub_menu_text_active_color, $sub_menu_text_active_color_css );

		// Drawer.
		$drawer_background_color_css = array(
			'.mzx-drawer-box'
			=> array(
				'background-color' => esc_html( $drawer_background_color ),
			),
		);

		$parse_css .= self::magazinex_parse_css( '#f8f8f8', $drawer_background_color, $drawer_background_color_css );

		// Footer column.
		$footer_col_background_color_css = array(
			'.mzx-footer-cols'
			=> array(
				'background-color' => esc_html( $footer_col_background_color ),
			),
		);

		$parse_css .= self::magazinex_parse_css( '', $footer_col_background_color, $footer_col_background_color_css );

		$footer_col_heading_color_css = array(
			'.mzx-footer-cols .widget-title, .mzx-footer-cols h1, .mzx-footer-cols h2, .mzx-footer-cols h3, .mzx-footer-cols h4, .mzx-footer-cols h5, .mzx-footer-cols h6, .mzx-footer-cols .mzb-post-list .mzb-post-heading h2'
			=> array(
				'color' => esc_html( $footer_col_heading_color ),
			),
		);

		$parse_css .= self::magazinex_parse_css( '', $footer_col_heading_color, $footer_col_heading_color_css );

		$footer_col_text_color_css = array(
			'.mzx-footer-cols'
			=> array(
				'color' => esc_html( $footer_col_text_color ),
			),
		);

		$parse_css .= self::magazinex_parse_css( '', $footer_col_text_color, $footer_col_text_color_css );

		$footer_col_link_color_css = array(
			'.mzx-footer-cols a, .mzx-footer-cols .mzb-post-list .mzb-post-title a, .mzx-footer-cols .mzb-post-list .mzb-post-date a'
			=> array(
				'color' => esc_html( $footer_col_link_color ),
			),
		);

		$parse_css .= self::magazinex_parse_css( '', $footer_col_link_color, $footer_col_link_color_css );

		// Footer bar.
		$footer_bar_background_color_css = array(
			'.mzx-footer-bar'
			=> array(
				'background-color' => esc_html( $footer_bar_background_color ),
			),
		);

		$parse_css .= self::magazinex_parse_css( '', $footer_bar_background_color, $footer_bar_background_color_css );

		$footer_bar_text_color_css = array(
			'.mzx-footer-bar-1,
			.mzx-footer-bar-2'
			=> array(
				'color' => esc_html( $footer_bar_text_color ),
			),
		);

		$parse_css .= self::magazinex_parse_css( '', $footer_bar_text_color, $footer_bar_text_color_css );

		$footer_bar_link_color_css = array(
			'.mzx-footer-bar-1 a,
			.mzx-footer-bar-2 a'
			=> array(
				'color' => esc_html( $footer_bar_link_color ),
			),
		);

		$parse_css .= self::magazinex_parse_css( '', $footer_bar_link_color, $footer_bar_link_color_css );

		$footer_bar_link_hover_color_css = array(
			'.mzx-footer-bar a:hover, .mzx-footer li a:hover'
			=> array(
				'color' => esc_html( $footer_bar_link_hover_color ),
			),
		);

		$parse_css .= self::magazinex_parse_css( '', $footer_bar_link_hover_color, $footer_bar_link_hover_color_css );

		$parse_css .= self::magazinex_editor_block_css();

		return $parse_css;
	}

	/**
	 * Parses CSS.
	 *
	 * @param string|array $default_value Default value.
	 * @param string|array $output_value  Updated value.
	 * @param array        $css_output    Array of CSS.
	 * @param string       $min_media     Min Media breakpoint.
	 * @param string       $max_media     Max Media breakpoint.
	 *
	 * @return string Generated CSS.
	 */
	public static function magazinex_parse_css( $default_value, $output_value, $css_output = array(), $min_media = '', $max_media = '' ) {

		// Return if default value matches.
		if ( $default_value == $output_value ) {
			return;
		}

		$parse_css = '';

		if ( is_array( $css_output ) && count( $css_output ) > 0 ) {

			foreach ( $css_output as $selector => $properties ) {

				if ( null === $properties ) {
					break;
				}

				if ( ! count( $properties ) ) {
					continue;
				}

				$temp_parse_css   = $selector . '{';
				$properties_added = 0;

				foreach ( $properties as $property => $value ) {

					if ( '' === $value ) {
						continue;
					}

					$properties_added ++;
					$temp_parse_css .= $property . ':' . $value . ';';
				}

				$temp_parse_css .= '}';

				if ( $properties_added > 0 ) {
					$parse_css .= $temp_parse_css;
				}
			}

			if ( '' !== $parse_css && ( '' !== $min_media || '' !== $max_media ) ) {

				$media_css       = '@media ';
				$min_media_css   = '';
				$max_media_css   = '';
				$media_separator = '';

				if ( '' !== $min_media ) {
					$min_media_css = '(min-width:' . $min_media . ')';
				}

				if ( '' !== $max_media ) {
					$max_media_css = '(max-width:' . $max_media . ')';
				}

				if ( '' !== $min_media && '' !== $max_media ) {
					$media_separator = ' and ';
				}

				$media_css .= $min_media_css . $media_separator . $max_media_css . '{' . $parse_css . '}';

				return $media_css;

			}
		}

		return $parse_css;
	}

	/**
	 * Returns the background CSS property for dynamic CSS generation.
	 *
	 * @param string|array $default_value Default value.
	 * @param string|array $output_value  Updated value.
	 * @param string       $selector      CSS selector.
	 *
	 * @return string|void Generated CSS for background CSS property.
	 */
	public static function magazinex_parse_background_css( $default_value, $output_value, $selector ) {

		if ( $default_value === $output_value ) {
			return;
		}

		$parse_css = $selector . '{';

		// For background color.
		if ( isset( $output_value['background-color'] ) && ! empty( $output_value['background-color'] ) && ( $output_value['background-color'] !== $default_value['background-color'] ) ) {
			$parse_css .= 'background-color:' . $output_value['background-color'] . ';';
		}

		// For background image.
		if ( isset( $output_value['background-image'] ) && ! empty( $output_value['background-image'] ) && ( $output_value['background-image'] !== $default_value['background-image'] ) ) {
			$parse_css .= 'background-image:url(' . $output_value['background-image'] . ');';
		}

		// For background position.
		if ( isset( $output_value['background-position'] ) && ! empty( $output_value['background-position'] ) && ( $output_value['background-position'] !== $default_value['background-position'] ) ) {
			$parse_css .= 'background-position:' . $output_value['background-position'] . ';';
		}

		// For background size.
		if ( isset( $output_value['background-size'] ) && ! empty( $output_value['background-size'] ) && ( $output_value['background-size'] !== $default_value['background-size'] ) ) {
			$parse_css .= 'background-size:' . $output_value['background-size'] . ';';
		}

		// For background attachment.
		if ( isset( $output_value['background-attachment'] ) && ! empty( $output_value['background-attachment'] ) && ( $output_value['background-attachment'] !== $default_value['background-attachment'] ) ) {
			$parse_css .= 'background-attachment:' . $output_value['background-attachment'] . ';';
		}

		// For background repeat.
		if ( isset( $output_value['background-repeat'] ) && ! empty( $output_value['background-repeat'] ) && ( $output_value['background-repeat'] !== $default_value['background-repeat'] ) ) {
			$parse_css .= 'background-repeat:' . $output_value['background-repeat'] . ';';
		}

		$parse_css .= '}';

		return $parse_css;
	}

	/**
	 * Returns the background CSS property for editor.
	 *
	 * @param string|array $default_value Default value.
	 * @param string|array $output_value  Updated value.
	 * @param string       $selector      CSS selector.
	 *
	 * @return string|void Generated CSS for background CSS property.
	 */
	public static function magazinex_editor_block_css() {
		$parse_css = '';

		$primary_color     = get_theme_mod( 'magazinex_primary_color', '#C7AB62' );
		$primary_color_css = array(
			'.mzb-featured-posts,
			.mzb-social-icon,
			.mzb-featured-categories,
			.mzb-social-icons-insert'
			=> array(
				'--color--light--primary' => MagazineX_Utils::adjust_color_opacity( $primary_color, 10 ),
			),

			'body'
			=> array(
				'--color--light--primary' => esc_html( $primary_color ),
				'--color--primary'        => esc_html( $primary_color ),
			),
		);

		$parse_css .= self::magazinex_parse_css( '#C7AB62', $primary_color, $primary_color_css );

		return $parse_css;

	}
}
