<?php
/**
 * Class to register panels and sections for customize options.
 *
 * Class MagazineX_Customizer_Register_Section_Panel
 *
 * @package    MagazineX
 * @since      1.0.0
 */

// Exit if accessed directly.
defined( 'ABSPATH' ) || exit;

/**
 * Class to register panels and sections for customize options.
 *
 * Class MagazineX_Customizer_Register_Section_Panel
 */
class MagazineX_Customizer_Register_Section_Panel extends MagazineX_Customize_Base_Option {

	/**
	 * Include customize options.
	 *
	 * @param array                 $options      Customize options provided via the theme.
	 * @param \WP_Customize_Manager $wp_customize Theme Customizer object.
	 *
	 * @return mixed|void Customizer options for registering panels, sections as well as controls.
	 */
	public function register_options( $options, $wp_customize ) {

		$configs = array(

			/**
			 * Panels.
			 */
			array(
				'name'     => 'magazinex_global_panel',
				'type'     => 'panel',
				'title'    => esc_html__( 'Global', 'magazinex' ),
				'priority' => 10,
			),

			array(
				'name'     => 'magazinex_header_navigation_panel',
				'type'     => 'panel',
				'title'    => esc_html__( 'Header & Navigation', 'magazinex' ),
				'priority' => 20,
			),

			array(
				'name'     => 'magazinex_content_panel',
				'type'     => 'panel',
				'title'    => esc_html__( 'Content', 'magazinex' ),
				'priority' => 30,
			),

			array(
				'name'     => 'magazinex_footer_panel',
				'type'     => 'panel',
				'title'    => esc_html__( 'Footer', 'magazinex' ),
				'priority' => 40,
			),

			/**
			 * Global.
			 */
			array(
				'name'     => 'magazinex_global_colors_section',
				'type'     => 'section',
				'title'    => esc_html__( 'Colors', 'magazinex' ),
				'panel'    => 'magazinex_global_panel',
				'priority' => 10,
			),

			array(
				'name'     => 'magazinex_global_category_colors_section',
				'type'     => 'section',
				'title'    => esc_html__( 'Category Colors', 'magazinex' ),
				'panel'    => 'magazinex_global_panel',
				'priority' => 20,
			),

			array(
				'name'     => 'magazinex_global_container_section',
				'type'     => 'section',
				'title'    => esc_html__( 'Container', 'magazinex' ),
				'panel'    => 'magazinex_global_panel',
				'priority' => 40,
			),

			array(
				'name'     => 'magazinex_sidebar_layout_section',
				'type'     => 'section',
				'title'    => esc_html__( 'Sidebar', 'magazinex' ),
				'panel'    => 'magazinex_global_panel',
				'priority' => 50,
			),

			/**
			 * Header.
			 */
			array(
				'name'     => 'magazinex_top_bar_section',
				'type'     => 'section',
				'title'    => esc_html__( 'Top Bar', 'magazinex' ),
				'panel'    => 'magazinex_header_navigation_panel',
				'priority' => 10,
			),

			array(
				'name'             => 'magazinex_top_bar_section_separator',
				'type'             => 'section',
				'panel'            => 'magazinex_header_navigation_panel',
				'priority'         => 15,
				'section_callback' => 'MagazineX_WP_Customize_Separator',
			),

			array(
				'name'     => 'title_tagline',
				'type'     => 'section',
				'title'    => esc_html__( 'Site Identity', 'magazinex' ),
				'panel'    => 'magazinex_header_navigation_panel',
				'priority' => 20,
			),

			array(
				'name'     => 'magazinex_main_header_section',
				'type'     => 'section',
				'title'    => esc_html__( 'Main Header', 'magazinex' ),
				'panel'    => 'magazinex_header_navigation_panel',
				'priority' => 30,
			),

			array(
				'name'     => 'magazinex_primary_menu_section',
				'type'     => 'section',
				'title'    => esc_html__( 'Primary Menu', 'magazinex' ),
				'panel'    => 'magazinex_header_navigation_panel',
				'priority' => 40,
			),

			array(
				'name'             => 'magazinex_main_header_section_separator',
				'type'             => 'section',
				'panel'            => 'magazinex_header_navigation_panel',
				'priority'         => 45,
				'section_callback' => 'MagazineX_WP_Customize_Separator',
			),

			array(
				'name'     => 'magazinex_header_action_section',
				'type'     => 'section',
				'title'    => esc_html__( 'Header Action', 'magazinex' ),
				'panel'    => 'magazinex_header_navigation_panel',
				'priority' => 50,
			),

			array(
				'name'     => 'magazinex_search_section',
				'type'     => 'section',
				'title'    => esc_html__( 'Search', 'magazinex' ),
				'panel'    => 'magazinex_header_navigation_panel',
				'priority' => 60,
			),

			array(
				'name'             => 'magazinex_header_actions_section_separator',
				'type'             => 'section',
				'panel'            => 'magazinex_header_navigation_panel',
				'priority'         => 65,
				'section_callback' => 'MagazineX_WP_Customize_Separator',
			),

			array(
				'name'     => 'magazinex_page_header_section',
				'type'     => 'section',
				'title'    => esc_html__( 'Page Header', 'magazinex' ),
				'panel'    => 'magazinex_header_navigation_panel',
				'priority' => 70,
			),

			array(
				'name'     => 'magazinex_breadcrumb_section',
				'type'     => 'section',
				'title'    => esc_html__( 'Breadcrumb', 'magazinex' ),
				'panel'    => 'magazinex_header_navigation_panel',
				'priority' => 80,
			),

			array(
				'name'             => 'magazinex_page_header_section_separator',
				'type'             => 'section',
				'panel'            => 'magazinex_header_navigation_panel',
				'priority'         => 85,
				'section_callback' => 'MagazineX_WP_Customize_Separator',
			),


			array(
				'name'     => 'magazinex_drawer_toggle_section',
				'type'     => 'section',
				'title'    => esc_html__( 'Drawer Toggle', 'magazinex' ),
				'panel'    => 'magazinex_header_navigation_panel',
				'priority' => 90,
			),

			/**
			 * Content.
			 */
			array(
				'name'     => 'magazinex_blog_section',
				'type'     => 'section',
				'title'    => esc_html__( 'Blog', 'magazinex' ),
				'panel'    => 'magazinex_content_panel',
				'priority' => 10,
			),

			array(
				'name'     => 'magazinex_single_post_section',
				'type'     => 'section',
				'title'    => esc_html__( 'Single Post', 'magazinex' ),
				'panel'    => 'magazinex_content_panel',
				'priority' => 20,
			),

			/**
			 * Footer.
			 */
			array(
				'name'     => 'magazinex_footer_column_section',
				'type'     => 'section',
				'title'    => esc_html__( 'Footer Column', 'magazinex' ),
				'panel'    => 'magazinex_footer_panel',
				'priority' => 10,
			),

			array(
				'name'     => 'magazinex_footer_bar_section',
				'type'     => 'section',
				'title'    => esc_html__( 'Footer Bar', 'magazinex' ),
				'panel'    => 'magazinex_footer_panel',
				'priority' => 20,
			),

			array(
				'name'     => 'magazinex_scroll_to_top',
				'type'     => 'section',
				'title'    => esc_html__( 'Scroll to Top', 'magazinex' ),
				'panel'    => 'magazinex_footer_panel',
				'priority' => 30,
			),

			array(
				'name'             => 'magazinex_panel_separator',
				'type'             => 'section',
				'priority'         => 75,
				'section_callback' => 'MagazineX_WP_Customize_Separator',
			),

			array(
				'name'             => 'magazinex_review_link_section',
				'type'             => 'section',
				'title'            => esc_html__( 'Leave a Review on .org', 'magazinex' ),
				'url'              => 'https://wordpress.org/support/theme/magazinex/reviews/?filter=5/#new-post',
				'priority'         => 200,
				'section_callback' => 'MagazineX_Upsell_Section',
			),
		);

		$options = array_merge( $options, $configs );

		return $options;
	}
}

return new MagazineX_Customizer_Register_Section_Panel();
