<?php
/**
 * Class to include Colors customize options.
 *
 * Class MagazineX_Customize_Colors_Options
 *
 * @package    MagazineX
 * @since      1.0.0
 */

// Exit if accessed directly.
defined( 'ABSPATH' ) || exit;

/**
 * Class to include Colors customize options.
 *
 * Class MagazineX_Customize_Colors_Options
 */
class MagazineX_Customize_Colors_Options extends MagazineX_Customize_Base_Option {

	/**
	 * Include customize options.
	 *
	 * @param array                 $options      Customize options provided via the theme.
	 * @param \WP_Customize_Manager $wp_customize Theme Customizer object.
	 *
	 * @return mixed|void Customizer options for registering panels, sections as well as controls.
	 */
	public function register_options( $options, $wp_customize ) {

		$configs = array(

			array(
				'name'     => 'magazinex_theme_color_heading',
				'type'     => 'control',
				'control'  => 'magazinex-title',
				'label'    => esc_html__( 'Theme Color', 'magazinex' ),
				'section'  => 'magazinex_global_colors_section',
				'priority' => 0,
			),

			array(
				'name'     => 'magazinex_primary_color_group',
				'default'  => '',
				'type'     => 'control',
				'control'  => 'magazinex-group',
				'label'    => esc_html__( 'Primary Color', 'magazinex' ),
				'section'  => 'magazinex_global_colors_section',
				'priority' => 10,
			),

			array(
				'name'     => 'magazinex_primary_color',
				'default'  => '#BA81FF',
				'type'     => 'sub-control',
				'control'  => 'magazinex-color',
				'section'  => 'magazinex_global_colors_section',
				'parent'   => 'magazinex_primary_color_group',
				'priority' => 10,
			),

			array(
				'name'     => 'magazinex_headings_color_heading',
				'type'     => 'control',
				'control'  => 'magazinex-title',
				'label'    => esc_html__( 'Headings', 'magazinex' ),
				'section'  => 'magazinex_global_colors_section',
				'priority' => 30,
			),

			array(
				'name'     => 'magazinex_headings_color_group',
				'type'     => 'control',
				'control'  => 'magazinex-group',
				'label'    => esc_html__( 'Headings', 'magazinex' ),
				'section'  => 'magazinex_global_colors_section',
				'priority' => 40,
			),

			array(
				'name'     => 'magazinex_headings_color',
				'default'  => '#111111',
				'type'     => 'sub-control',
				'control'  => 'magazinex-color',
				'section'  => 'magazinex_global_colors_section',
				'parent'   => 'magazinex_headings_color_group',
				'priority' => 40,
			),

			array(
				'name'     => 'magazinex_links_color_heading',
				'type'     => 'control',
				'control'  => 'magazinex-title',
				'label'    => esc_html__( 'Links', 'magazinex' ),
				'section'  => 'magazinex_global_colors_section',
				'priority' => 110,
			),

			array(
				'name'     => 'magazinex_links_color_group',
				'default'  => '',
				'type'     => 'control',
				'control'  => 'magazinex-group',
				'label'    => esc_html__( 'Links', 'magazinex' ),
				'section'  => 'magazinex_global_colors_section',
				'priority' => 120,
			),

			array(
				'name'     => 'magazinex_link_color',
				'label'    => esc_html__( 'Color', 'magazinex' ),
				'default'  => '#111111',
				'type'     => 'sub-control',
				'control'  => 'magazinex-color',
				'parent'   => 'magazinex_link_color_group',
				'tab'      => esc_html__( 'Normal', 'magazinex' ),
				'section'  => 'magazinex_global_colors_section',
				'priority' => 120,
			),

			array(
				'name'     => 'magazinex_link_hover_color',
				'label'    => esc_html__( 'Color', 'magazinex' ),
				'default'  => '#BA81FF',
				'type'     => 'sub-control',
				'control'  => 'magazinex-color',
				'parent'   => 'magazinex_link_color_group',
				'tab'      => esc_html__( 'Hover', 'magazinex' ),
				'section'  => 'magazinex_global_colors_section',
				'priority' => 120,
			),
		);

		$options = array_merge( $options, $configs );

		return $options;
	}
}

return new MagazineX_Customize_Colors_Options();
