<?php
/**
 * Class to include header bar customize options.
 *
 * Class MagazineX_Customize_Header_Bar_Options
 *
 * @package    MagazineX
 * @since      1.0.0
 */

// Exit if accessed directly.
defined( 'ABSPATH' ) || exit;

/**
 * Class to include header bar customize options.
 *
 * Class MagazineX_Customize_Header_Bar_Options
 */
class MagazineX_Customize_Header_Bar_Options extends MagazineX_Customize_Base_Option {

	/**
	 * Include customize options.
	 *
	 * @param array                 $options      Customize options provided via the theme.
	 * @param \WP_Customize_Manager $wp_customize Theme Customizer object.
	 *
	 * @return mixed|void Customizer options for registering panels, sections as well as controls.
	 */
	public function register_options( $options, $wp_customize ) {

		$configs = array(

			array(
				'name'     => 'magazinex_header_bar_general_heading',
				'type'     => 'control',
				'control'  => 'magazinex-title',
				'label'    => esc_html__( 'General', 'magazinex' ),
				'section'  => 'magazinex_top_bar_section',
				'priority' => 10,
			),

			array(
				'name'     => 'magazinex_enable_header_bar',
				'default'  => 0,
				'type'     => 'control',
				'control'  => 'magazinex-toggle',
				'label'    => esc_html__( 'Enable', 'magazinex' ),
				'section'  => 'magazinex_top_bar_section',
				'priority' => 20,
			),

			array(
				'name'          => 'magazinex_navigate_header_bar_columns',
				'type'          => 'control',
				'control'       => 'magazinex-navigate',
				'section'       => 'magazinex_top_bar_section',
				'navigate_info' => array(
					'target_container' => 'section',
					'target_id'        => 'sidebar-widgets-mzx-header-bar-1',
					'target_label'     => esc_html__( 'Header Column', 'magazinex' ),
				),
				'dependency'    => array(
					'magazinex_enable_header_bar',
					'==',
					true,
				),
				'priority'      => 20,
			),

			array(
				'name'       => 'magazinex_header_bar_background_group',
				'type'       => 'control',
				'control'    => 'magazinex-group',
				'label'      => esc_html__( 'Background', 'magazinex' ),
				'section'    => 'magazinex_top_bar_section',
				'priority'   => 50,
				'dependency' => array(
					'magazinex_enable_header_bar',
					'==',
					true,
				),
			),

			array(
				'name'       => 'magazinex_header_bar_background',
				'default'    => array(
					'background-color'      => '#F2F3FF',
					'background-image'      => '',
					'background-repeat'     => 'repeat',
					'background-position'   => 'center center',
					'background-size'       => 'contain',
					'background-attachment' => 'scroll',
				),
				'type'       => 'sub-control',
				'control'    => 'magazinex-background',
				'section'    => 'magazinex_top_bar_section',
				'parent'     => 'magazinex_header_bar_background_group',
				'priority'   => 60,
				'dependency' => array(
					'magazinex_enable_header_bar',
					'==',
					true,
				),
			),
		);

		$options = array_merge( $options, $configs );

		return $options;
	}
}

return new MagazineX_Customize_Header_Bar_Options();
