<?php
/**
 * Class to include primary header customize options.
 *
 * Class MagazineX_Customize_Primary_Header_Options
 *
 * @package    MagazineX
 * @since      1.0.0
 */

// Exit if accessed directly.
defined( 'ABSPATH' ) || exit;

/**
 * Class to include primary header customize options.
 *
 * Class MagazineX_Customize_Primary_Header_Options
 */
class MagazineX_Customize_Primary_Header_Options extends MagazineX_Customize_Base_Option {

	/**
	 * Include customize options.
	 *
	 * @param array $options Customize options provided via the theme.
	 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
	 *
	 * @return mixed|void Customizer options for registering panels, sections as well as controls.
	 */
	public function register_options( $options, $wp_customize ) {

		$configs = array(

			array(
				'name'     => 'magazinex_main_header_general_heading',
				'type'     => 'control',
				'control'  => 'magazinex-title',
				'label'    => esc_html__( 'General', 'magazinex' ),
				'section'  => 'magazinex_main_header_section',
				'priority' => 10,
			),

			array(
				'name'     => 'magazinex_main_header_layout',
				'default'  => 'layout-1',
				'type'     => 'control',
				'control'  => 'select',
				'label'    => esc_html__( 'Layout', 'magazinex' ),
				'section'  => 'magazinex_main_header_section',
				'choices'  => array(
					'layout-1' => esc_html__( 'Layout 1', 'magazinex' ),
					'layout-2' => esc_html__( 'Layout 2', 'magazinex' ),
				),
				'priority' => 20,
			),

			array(
				'name'       => 'magazinex_main_header_layout_1_style',
				'default'    => 'style-1',
				'type'       => 'control',
				'control'    => 'magazinex-radio-image',
				'label'      => esc_html__( 'Advanced Style', 'magazinex' ),
				'section'    => 'magazinex_main_header_section',
				'choices'    => apply_filters(
					'magazinex_main_header_layout_1_style_choices',
					array(
						'style-1' => array(
							'label' => '',
							'url'   => MAGAZINEX_ADMIN_IMAGES_URL . '/layout-1-style-1.svg',
						),
					),
				),
				'dependency' => array(
					'magazinex_main_header_layout',
					'===',
					'layout-1',
				),
				'priority'   => 30,
			),

			array(
				'name'       => 'magazinex_main_header_layout_2_style',
				'default'    => 'style-1',
				'type'       => 'control',
				'control'    => 'magazinex-radio-image',
				'section'    => 'magazinex_main_header_section',
				'choices'    => apply_filters(
					'magazinex_main_header_layout_2_style_choices',
					array(
						'style-1' => array(
							'label' => '',
							'url'   => MAGAZINEX_ADMIN_IMAGES_URL . '/layout-2-style-1.svg',
						),
					),
				),
				'dependency' => array(
					'magazinex_main_header_layout',
					'===',
					'layout-2',
				),
				'priority'   => 40,
			),

			array(
				'name'       => 'magazinex_main_header_heading',
				'type'       => 'control',
				'control'    => 'magazinex-title',
				'label'      => esc_html__( 'Primary Header', 'magazinex' ),
				'section'    => 'magazinex_main_header_section',
				'dependency' => array(
					'magazinex_main_header_layout',
					'===',
					'layout-1',
				),
				'priority'   => 70,
			),

			array(
				'name'       => 'magazinex_main_header_background_group',
				'type'       => 'control',
				'control'    => 'magazinex-group',
				'label'      => esc_html__( 'Background', 'magazinex' ),
				'section'    => 'magazinex_main_header_section',
				'dependency' => array(
					'magazinex_main_header_layout',
					'===',
					'layout-1',
				),
				'priority'   => 80,
			),

			array(
				'name'       => 'magazinex_main_header_background',
				'default'    => array(
					'background-color'      => '#FFFFFF',
					'background-image'      => '',
					'background-repeat'     => 'repeat',
					'background-position'   => 'center center',
					'background-size'       => 'cover',
					'background-attachment' => 'scroll',
				),
				'type'       => 'sub-control',
				'control'    => 'magazinex-background',
				'section'    => 'magazinex_main_header_section',
				'parent'     => 'magazinex_main_header_background_group',
				'dependency' => array(
					'magazinex_main_header_layout',
					'===',
					'layout-1',
				),
				'priority'   => 80,
			),
		);

		$options = array_merge( $options, $configs );

		return $options;
	}
}

return new MagazineX_Customize_Primary_Header_Options();
