<?php
/**
 * Class to include search customize options.
 *
 * Class MagazineX_Customize_Search_Options
 *
 * @package    MagazineX
 * @since      1.0.0
 */

// Exit if accessed directly.
defined( 'ABSPATH' ) || exit;

/**
 * Class to include search customize options.
 *
 * Class MagazineX_Customize_Search_Options
 */
class MagazineX_Customize_Search_Options extends MagazineX_Customize_Base_Option {

	/**
	 * Include customize options.
	 *
	 * @param array                 $options      Customize options provided via the theme.
	 * @param \WP_Customize_Manager $wp_customize Theme Customizer object.
	 *
	 * @return mixed|void Customizer options for registering panels, sections as well as controls.
	 */
	public function register_options( $options, $wp_customize ) {

		$configs = array(

			array(
				'name'     => 'magazinex_search_general_heading',
				'type'     => 'control',
				'control'  => 'magazinex-title',
				'label'    => esc_html__( 'General', 'magazinex' ),
				'section'  => 'magazinex_search_section',
				'priority' => 10,
			),

			array(
				'name'     => 'magazinex_enable_header_search',
				'default'  => 1,
				'type'     => 'control',
				'control'  => 'magazinex-toggle',
				'label'    => esc_html__( 'Enable', 'magazinex' ),
				'section'  => 'magazinex_search_section',
				'priority' => 20,
			),

		);

		$options = array_merge( $options, $configs );

		return $options;
	}
}

return new MagazineX_Customize_Search_Options();
