<?php
/**
 * Class to include site identity customize options.
 *
 * Class MagazineX_Customize_Site_Identity_Options
 *
 * @package    MagazineX
 * @since      1.0.0
 */

// Exit if accessed directly.
defined( 'ABSPATH' ) || exit;

/**
 * Class to include site identity customize options.
 *
 * Class MagazineX_Customize_Site_Identity_Options
 */
class MagazineX_Customize_Site_Identity_Options extends MagazineX_Customize_Base_Option {

	/**
	 * Include customize options.
	 *
	 * @param array                 $options      Customize options provided via the theme.
	 * @param \WP_Customize_Manager $wp_customize Theme Customizer object.
	 *
	 * @return mixed|void Customizer options for registering panels, sections as well as controls.
	 */
	public function register_options( $options, $wp_customize ) {

		$configs = array(

			array(
				'name'     => 'magazinex_logo_heading',
				'type'     => 'control',
				'control'  => 'magazinex-title',
				'label'    => esc_html__( 'Logo', 'magazinex' ),
				'section'  => 'title_tagline',
				'priority' => 10,
			),

			array(
				'name'        => 'magazinex_retina_logo',
				'type'        => 'control',
				'control'     => 'image',
				'label'       => esc_html__( 'Retina Logo', 'magazinex' ),
				'description' => esc_html__( 'Upload 2X times the size of your current logo. Eg: If your current logo size is 115*50 then upload 230*100 sized logo.', 'magazinex' ),
				'section'     => 'title_tagline',
				'priority'    => 30,
			),

			array(
				'name'        => 'magazinex_logo_height',
				'default'     => '',
				'suffix'      => 'px',
				'type'        => 'control',
				'control'     => 'magazinex-slider',
				'label'       => esc_html__( 'Height', 'magazinex' ),
				'section'     => 'title_tagline',
				'priority'    => 40,
				'input_attrs' => array(
					'min'  => 0,
					'max'  => 100,
					'step' => 1,
				),
			),

			array(
				'name'     => 'magazinex_site_icon_heading',
				'type'     => 'control',
				'control'  => 'magazinex-title',
				'label'    => esc_html__( 'Site Icon', 'magazinex' ),
				'section'  => 'title_tagline',
				'priority' => 50,
			),

			array(
				'name'     => 'magazinex_site_title_heading',
				'type'     => 'control',
				'control'  => 'magazinex-title',
				'label'    => esc_html__( 'Site Title', 'magazinex' ),
				'section'  => 'title_tagline',
				'priority' => 60,
			),

			array(
				'name'     => 'magazinex_site_title_colors_group',
				'default'  => '',
				'type'     => 'control',
				'control'  => 'magazinex-group',
				'label'    => esc_html__( 'Colors', 'magazinex' ),
				'section'  => 'title_tagline',
				'priority' => 80,
			),

			array(
				'name'     => 'magazinex_site_title_color',
				'default'  => '#181818',
				'type'     => 'sub-control',
				'control'  => 'magazinex-color',
				'parent'   => 'magazinex_site_title_colors_group',
				'tab'      => esc_html__( 'Normal', 'magazinex' ),
				'section'  => 'title_tagline',
				'priority' => 80,
			),

			array(
				'name'     => 'magazinex_site_title_hover_color',
				'default'  => '#C7AB62',
				'type'     => 'sub-control',
				'control'  => 'magazinex-color',
				'parent'   => 'magazinex_site_title_colors_group',
				'tab'      => esc_html__( 'Hover', 'magazinex' ),
				'section'  => 'title_tagline',
				'priority' => 80,
			),

			array(
				'name'     => 'magazinex_tagline_heading',
				'type'     => 'control',
				'control'  => 'magazinex-title',
				'label'    => esc_html__( 'Tagline', 'magazinex' ),
				'section'  => 'title_tagline',
				'priority' => 100,
			),

			array(
				'name'     => 'magazinex_tagline_colors_group',
				'default'  => '',
				'type'     => 'control',
				'control'  => 'magazinex-group',
				'label'    => esc_html__( 'Colors', 'magazinex' ),
				'section'  => 'title_tagline',
				'priority' => 120,
			),

			array(
				'name'     => 'magazinex_tagline_color',
				'default'  => '#000',
				'type'     => 'sub-control',
				'control'  => 'magazinex-color',
				'parent'   => 'magazinex_tagline_colors_group',
				'tab'      => esc_html__( 'Normal', 'magazinex' ),
				'section'  => 'title_tagline',
				'priority' => 120,
			),
		);

		$options = array_merge( $options, $configs );

		return $options;
	}
}

return new MagazineX_Customize_Site_Identity_Options();
