<?php
/**
 * Page settings meta box class.
 *
 * @package    MagazineX
 * @since      MagazineX 1.0.2
 */

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

/**
 * Page settings meta box class.
 *
 * Class MagazineX_Meta_Box_Page_Settings
 */
class MagazineX_Meta_Box_Page_Settings {

    /**
     * Meta box render content callback for video post format only.
     *
     * @param WP_Post $post Current post object.
     */
    public static function render_video_url( $post ) {

        // Add nonce for security and authentication.
        wp_nonce_field( 'magazinex_save_data', 'magazinex_meta_nonce' );

        global $post;

        // Video URL.
        $magazinex_video_url = get_post_meta( $post->ID, 'video_url', true );
        ?>

        <p>
            <input type="text" class="widefat" name="video_url" id="video_url"
                   value="<?php echo esc_url( $magazinex_video_url ); ?>"
            />
        </p>

        <?php

    }

    /**
     * Save meta box content.
     *
     * @param int $post_id Post ID.
     */
    public static function save( $post_id ) {

        $magazinex_video_url = isset( $_POST['video_url'] ) ? esc_url_raw( $_POST['video_url'] ) : '';

        // Video post format video URL.
        if ( $magazinex_video_url ) {
            update_post_meta( $post_id, 'video_url', $magazinex_video_url );
        } else {
            delete_post_meta( $post_id, 'video_url' );
        }

        /**
         * Hook for page settings data save.
         */
        do_action( 'magazinex_page_settings_save', $post_id );

    }
}
