<?php
/**
 * Hooks for Header HTML markups.
 *
 * @package MagazineX
 * @since   1.0.0
 */

// Exit if accessed directly.
defined( 'ABSPATH' ) || exit;

if ( ! function_exists( 'magazinex_header_markup' ) ) {

	/**
	 * Adds MagazineX header markup.
	 *
	 * @return void
	 */
	function magazinex_header_markup() {
		do_action( 'magazinex_header_markup_before' );
		?>

		<header id="mzx-masthead" class="mzx-header">
			<?php
			magazinex_header_bar();
			magazinex_main_header();
			magazinex_page_header();
			?>
		</header><!-- #masthead -->
		<?php
		do_action( 'magazinex_header_markup_after' );
	}

	add_action( 'magazinex_header', 'magazinex_header_markup' );
}

if ( ! function_exists( 'magazinex_header_bar_markup' ) ) {

	/**
	 * Adds MagazineX header bar markup.
	 *
	 * @return void
	 */
	function magazinex_header_bar_markup() {
		do_action( 'magazinex_header_bar_markup_before' );

		$header_bar = get_theme_mod( 'magazinex_enable_header_bar', 0 );

		if ( 1 === $header_bar ) :
			if ( magazinex_is_magazinex_pro_active() ) {
				$mzx_header_bar_widgets_style = get_theme_mod( 'magazinex_header_bar_layout', 'layout-3' );
			} else {
				$mzx_header_bar_widgets_style = 'layout-3';
			}
			$header_bar_sidebar_classes = apply_filters(
				'mzx_header_bar_sidebar_filter',
				array(
					'layout-1' => array(
						'mzx-header-bar-1',
					),
					'layout-2' => array(
						'mzx-header-bar-1',
						'mzx-header-bar-2',
					),
					'layout-3' => array(
						'mzx-header-bar-1',
						'mzx-header-bar-2',
						'mzx-header-bar-3',
					),
				)
			);
			?>
			<div class="mzx-site-top-bar">
				<div class="mzx-container">
					<div class="mzx-row <?php mzx_header_bar_widget_container_class(); ?>">
						<?php

						foreach ( $header_bar_sidebar_classes as $header_bar_sidebar_key => $header_bar_sidebar_class ) {
							foreach ( $header_bar_sidebar_class as $header_bar_sidebar_display ) {

								if ( $header_bar_sidebar_key === $mzx_header_bar_widgets_style ) {
									?>
									<div class="mzx-header-widget-area <?php echo esc_attr( $header_bar_sidebar_display ); ?>">
										<?php if ( is_active_sidebar( $header_bar_sidebar_display ) ) : ?>
											<?php dynamic_sidebar( $header_bar_sidebar_display ); ?>
										<?php endif; ?>
									</div>
									<?php
								}
							}
						}
						?>
					</div>
				</div>
			</div><!-- .mzx-footer-cols -->
			<?php
		endif;
		do_action( 'magazinex_header_bar_markup_after' );
	}

	add_action( 'magazinex_header_bar', 'magazinex_header_bar_markup' );
}

if ( ! function_exists( 'magazinex_main_header_markup' ) ) {
	/**
	 * Adds MagazineX masthead level 1 markup.
	 *
	 * @return void
	 */
	function magazinex_main_header_markup() {
		get_template_part( 'template-parts/header/header', 'primary' );
	}

	add_action( 'magazinex_main_header', 'magazinex_main_header_markup' );
}


if ( ! function_exists( 'magazinex_main_header_layout_1_markup' ) ) {
	/**
	 * Adds MagazineX masthead level 1 markup.
	 *
	 * @return void
	 */
	function magazinex_main_header_layout_1_markup() {

		get_template_part( 'template-parts/header/header', 'layout-1' );

	}

	add_action( 'magazinex_main_header_layout_1', 'magazinex_main_header_layout_1_markup' );
}

if ( ! function_exists( 'magazinex_main_header_layout_2_markup' ) ) {
	/**
	 * Adds MagazineX masthead level 1 markup.
	 *
	 * @return void
	 */
	function magazinex_main_header_layout_2_markup() {

		get_template_part( 'template-parts/header/header', 'layout-2' );

	}

	add_action( 'magazinex_main_header_layout_2', 'magazinex_main_header_layout_2_markup' );
}

if ( ! function_exists( 'magazinex_header_1_markup' ) ) {
	/**
	 * Adds MagazineX masthead level 1 markup.
	 *
	 * @return void
	 */
	function magazinex_header_1_markup() {
		?>

		<div id="mzx-header-1" class="mzx-header-1">
			<div class="mzx-container">
				<div class="mzx-row">
					<div class="mzx-header-col-1">
					<?php magazinex_site_branding(); ?>
					</div>
					<div class="mzx-header-col-2">
					<?php magazinex_header_blocks(); ?>
					</div>
				</div> <!-- .mzx-row -->
			</div> <!-- .mzx-container -->
		</div> <!-- /.mzx-header-1 -->
		<?php
	}

	add_action( 'magazinex_header_1', 'magazinex_header_1_markup' );
}

if ( ! function_exists( 'magazinex_site_branding_markup' ) ) {

	/**
	 * Adds MagazineX site branding markup.
	 *
	 * @return void
	 */
	function magazinex_site_branding_markup() {
		?>
			<div id="mzx-site-branding" class="mzx-site-branding">
				<?php the_custom_logo(); ?>
				<div class="mzx-site-info">
					<?php
					$logo = get_theme_mod( 'custom_logo' );

					if ( ! has_custom_logo() && ! $logo ) :
						if ( is_front_page() && is_home() ) :
							?>
						<h1 class="mzx-site-title">
							<a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home">
								<?php bloginfo( 'name' ); ?>
							</a>
						</h1>
						<?php else : ?>
						<p class="mzx-site-title">
							<a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home">
								<?php bloginfo( 'name' ); ?>
							</a>
						</p>
							<?php
						endif;
						?>
					<p class="mzx-site-description">
						<?php
						echo get_bloginfo( 'description', 'display' ); // phpcs:ignore WordPress.XSS.EscapeOutput.OutputNotEscaped
						?>
					</p><!-- .mzx-site-description -->
						<?php
				endif;
					?>
			</div>
		</div><!-- .mzx-site-branding -->
		<?php
	}

	add_action( 'magazinex_site_branding', 'magazinex_site_branding_markup' );
}

if ( ! function_exists( 'magazinex_header_blocks_markup' ) ) {

	/**
	 * Adds MagazineX header blocks markup.
	 *
	 * @return void
	 */
	function magazinex_header_blocks_markup() {
		if ( is_active_sidebar( 'mzx-header-sidebar' ) ) :
			?>
			<div id="header-right-sidebar" class="clearfix">
				<?php dynamic_sidebar( 'mzx-header-sidebar' ); ?>
			</div>

			<?php
		endif;
	}

	add_action( 'magazinex_header_blocks', 'magazinex_header_blocks_markup' );
}

if ( ! function_exists( 'magazinex_header_2_markup' ) ) {

	/**
	 * Adds MagazineX masthead level 2 markup.
	 *
	 * @return void
	 */
	function magazinex_header_2_markup() {
		?>

		<div id="mzx-header-2" class="mzx-header-2">
			<div class="mzx-container">
				<div class="mzx-row">
					<?php magazinex_header_drawer(); ?>

					<?php magazinex_mobile_menu(); ?>

					<?php magazinex_mobile_menu_nav(); ?>

					<?php magazinex_primary_menu(); ?>

					<?php magazinex_header_actions(); ?>
				</div> <!-- .mzx-row -->

			</div> <!-- .mzx-container -->
		</div> <!-- /.mzx-header-2 -->
		<?php
	}

	add_action( 'magazinex_header_2', 'magazinex_header_2_markup' );
}

if ( ! function_exists( 'magazinex_header_drawer_markup' ) ) {

	/**
	 * Adds MagazineX header drawer toggle markup.
	 *
	 * @return void
	 */
	function magazinex_header_drawer_markup() {
		$drawer_menu = get_theme_mod( 'magazinex_enable_header_drawer_toggle', 0 );

		if ( 1 === $drawer_menu ) :
			?>
			<div id="mzx-header-drawer" class="mzx-header-drawer">
				<a href="#" class="mzx-drawer-toggle" aria-controls="mzx-drawer-box" aria-expanded="false">
					<?php magazinex_get_icon( 'drawer' ); ?>
					<!-- Toggle button for mobile menu. -->
				</a>

				<div id="mzx-drawer-box" class="mzx-drawer-box">
					<!-- Close button for secondary menu. -->
					<a href="#" class="close-secondary-menu" aria-controls="mzx-drawer-box" aria-expanded="false">
						<?php magazinex_get_icon( 'close-circle' ); ?>
					</a>
					<div class="mzx-drawer-content">
						<?php
						$sidebar_id = 'mzx-drawer-sidebar';

						if ( is_active_sidebar( $sidebar_id ) ) :
							dynamic_sidebar( $sidebar_id );
						endif;
						?>
					</div>
				</div><!-- #drawer -->
			</div>
			<?php
		endif;
	}

	add_action( 'magazinex_header_drawer', 'magazinex_header_drawer_markup' );
}

if ( ! function_exists( 'magazinex_mobile_menu_markup' ) ) {

	/**
	 * Adds MagazineX mobile navigation markup.
	 *
	 * @return void
	 */
	function magazinex_mobile_menu_markup() {
		?>

		<div id="mzx-toggle-menu" class="mzx-toggle-menu">
			<a href="#" class="mzx-menu-toggle" aria-controls="mzx-mobile-nav" aria-expanded="false">
				<?php magazinex_get_icon( 'plus' ); ?>
				<?php magazinex_get_icon( 'menu-close' ); ?>
			</a>
		</div>
		<?php
	}

	add_action( 'magazinex_mobile_menu', 'magazinex_mobile_menu_markup' );
}

if ( ! function_exists( 'magazinex_mobile_menu_nav_markup' ) ) {

	/**
	 * Adds MagazineX mobile navigation markup.
	 *
	 * @return void
	 */
	function magazinex_mobile_menu_nav_markup() {
		?>
			<nav id="mzx-mobile-nav" class="mzx-mobile-nav">
				<?php
				if ( has_nav_menu( 'mzx-menu-primary' ) ) {
					wp_nav_menu(
						array(
							'theme_location' => 'mzx-menu-primary',
							'menu_class'     => '"mzx-mobile-menu"',
							'menu_id'        => '"mzx-mobile-menu"',
							'container'      => '',
						)
					);

				} else {
					wp_page_menu(
						array(
							'menu_class' => 'mzx-toggle-menu',
							'menu_id'    => 'toggle-menu',
							'container'  => 'ul',
							'before'     => '',
							'after'      => '',
						)
					);
				}
				?>
			</nav> <!-- /.mzx-mobile-navigation -->
		<?php
	}

	add_action( 'magazinex_mobile_menu_nav', 'magazinex_mobile_menu_nav_markup' );
}

if ( ! function_exists( 'magazinex_primary_menu_markup' ) ) {

	/**
	 * Adds MagazineX main navigation markup.
	 *
	 * @return void
	 */
	function magazinex_primary_menu_markup() {
		?>

		<nav id="mzx-primary-nav" class="mzx-primary-nav <?php magazinex_primary_menu_class(); ?> ">
			<?php
			if ( has_nav_menu( 'mzx-menu-primary' ) ) {
				wp_nav_menu(
					array(
						'theme_location' => 'mzx-menu-primary',
						'menu_id'        => 'mzx-primary-menu',
						'container'      => '',
					)
				);
			} else {
				wp_page_menu(
					array(
						'menu_class' => 'mzx-primary-menu',
						'container'  => 'ul',
						'before'     => '',
						'after'      => '',
					)
				);
			}
			?>

		</nav><!--#mzx-primary-nav-->
		<?php
	}

	add_action( 'magazinex_primary_menu', 'magazinex_primary_menu_markup' );
}

if ( ! function_exists( 'magazinex_header_actions_markup' ) ) {

	/**
	 * Adds MagazineX main navigation markup.
	 *
	 * @return void
	 */
	function magazinex_header_actions_markup() {
		$header_action_enable = get_theme_mod( 'magazinex_enable_header_action', 1 );
		$search_icon_enable   = get_theme_mod( 'magazinex_enable_header_search', 1 );

		if ( ( 1 === $header_action_enable ) || ( 1 === $search_icon_enable ) ) :

			?>

			<div class="<?php mzx_header_actions_container_class(); ?>">

				<?php
				if ( ( 1 === $header_action_enable ) ) :

					if ( is_active_sidebar( 'mzx-header-action-sidebar' ) ) {
						?>
					<div class="mzx-header-action mzx-block">
						<?php
							   dynamic_sidebar( 'mzx-header-action-sidebar' );
						?>
					</div>
						<?php
					}
				endif;

				if ( 1 === $search_icon_enable ) :
					?>
					<div class="mzx-header-action mzx-search">

						<?php
						if ( get_theme_mod( 'magazinex_enable_header_search', true ) ) {
							?>
							<div id="search" class="mzx-search">

								<?php get_search_form( true ); ?>

								<a href="#" class="mzx-searchbox-icon">
									<?php magazinex_get_icon( 'search' ); ?>
								</a>
								<a href="#" class="mzx-searchbox-close-icon">
									<?php magazinex_get_icon( 'close' ); ?>
								</a>
							</div>

							<?php
						}
						?>
					</div>
					<?php
				endif;
				?>
			</div>

			<?php
		endif;
	}

	add_action( 'magazinex_header_actions', 'magazinex_header_actions_markup' );
}

if ( ! function_exists( 'magazinex_page_header_markup' ) ) {

	/**
	 * Create markup for the page header.
	 *
	 * @return void
	 */
	function magazinex_page_header_markup() {
		if (
			is_front_page() ||
			is_404() ||
			(
				MagazineX_Utils::page_header_has_title() &&
				MagazineX_Utils::page_header_has_breadcrumbs()
			) ||
			(
				is_single() &&
				MagazineX_Utils::page_header_has_breadcrumbs()
			) ||
			is_page_template( 'page-templates/template-magazinex-page-builder.php' )
		) {
			return;
		}

		get_template_part( 'template-parts/page-header/page-header' );
	}

	add_action( 'magazinex_page_header', 'magazinex_page_header_markup' );
}

if ( ! function_exists( 'magazinex_change_logo_attr' ) ) {

	/**
	 * Change the logo image attr while retina logo is set.
	 *
	 * @param array $attr Array of attribute values for the image markup.
	 * @param object $attachment Image attachment post.
	 * @param int $size Requested image size.
	 *
	 * @return mixed
	 */
	function magazinex_change_logo_attr( $attr, $attachment, $size ) {

		$custom_logo = get_theme_mod( 'custom_logo' );
		$retina_logo = get_theme_mod( 'magazinex_retina_logo' );

		if ( $custom_logo && $retina_logo && isset( $attr['class'] ) && 'custom-logo' === $attr['class'] ) {
			$attr['srcset']  = '';
			$custom_logo_src = wp_get_attachment_image_src( $custom_logo, 'full' );
			$custom_logo_url = $custom_logo_src[0];

			// Set srcset.
			$attr['srcset'] = $custom_logo_url . ' 1x, ' . $retina_logo . ' 2x';
		}

		return $attr;
	}

	add_filter( 'wp_get_attachment_image_attributes', 'magazinex_change_logo_attr', 10, 3 );
}
